/***********************************
 * Ian Ayres and John J. Donohue III
 * Stanford Law Review
 * Response to Plassman and Whitley
 * Table 3b.1
 * Correcting coding errors in PW's Table 3
 * Lott's Newest County data
 * Dummy Variable Model
 * 1977-2000
 *********************/

clear
set more off
set mem 300m
set mat 800
use "../Lott6-w-region", clear
log using "ReplyT3b.1.log", replace
#delimit ;

drop if YEAR<1977;
drop if YEAR>2000;

replace YEAR=YEAR-1900;
gen regionyear=region*10000+YEAR;
tab regionyear, gen (ry) nof;

replace yradopt=0 if FIPSSTAT==25;
replace shallf=0 if FIPSSTAT==25;

areg  lratvio shallf aovio povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf using ReplyT3b.1.xls, replace noparen nolabel coefastr se 3aster;

areg  lratmur shallf aomur povrate Unemprt execrate rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf using ReplyT3b.1.xls, append noparen nolabel coefastr se 3aster;

areg  lratrap shallf aorap povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf using ReplyT3b.1.xls, append noparen nolabel coefastr se 3aster;

areg  lrataga shallf aoaga povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf using ReplyT3b.1.xls, append noparen nolabel coefastr se 3aster;

areg  lratrob shallf aorob povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf using ReplyT3b.1.xls, append noparen nolabel coefastr se 3aster;

areg  lratpro shallf aopro povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf using ReplyT3b.1.xls, append noparen nolabel coefastr se 3aster;

areg  lrataut shallf aoaut povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf using ReplyT3b.1.xls, append noparen nolabel coefastr se 3aster;

areg  lratbur shallf aobur povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf using ReplyT3b.1.xls, append noparen nolabel coefastr se 3aster;

areg  lratlar shallf aolar povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf using ReplyT3b.1.xls, append noparen nolabel coefastr se 3aster;


log close;