/******************************************
 * Ian Ayres and John J. Donohue III
 * Stanford Law Review
 * Response to Plassman and Whitley
 * Table 3b.3
 * Correcting coding errors in PW's Table 3
 * Lott's Newest County dataset
 * Hybrid Model
 * 1977-2000
 ******************************************/

clear
set more off
set mem 300m
set mat 800
use "../Lott6-w-region", clear
log using "ReplyT3b.3.log", replace
#delimit ;

drop if YEAR<1977;
drop if YEAR>2000;

replace YEAR=YEAR-1900;
gen regionyear=region*10000+YEAR;
tab regionyear, gen (ry) nof;

replace yradopt=0 if FIPSSTAT==25;
replace shallf=0 if FIPSSTAT==25;

drop aftr*;

gen aftr=0;
replace aftr=YEAR-yradopt if yradopt>77&YEAR>yradopt;
gen ttt=YEAR-76 if yradopt>77&yradopt<98;
replace ttt=0 if ttt==.;

areg  lratvio shallf aftr ttt aovio povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf aftr using ReplyT3b.3.xls, replace noparen nolabel coefastr se 3aster;

areg  lratmur shallf aftr ttt aomur povrate Unemprt execrate rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf aftr using ReplyT3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lratrap shallf aftr ttt aorap povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf aftr using ReplyT3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lrataga shallf aftr ttt aoaga povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf aftr using ReplyT3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lratrob shallf aftr ttt aorob povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf aftr using ReplyT3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lratpro shallf aftr ttt aopro povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf aftr using ReplyT3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lrataut shallf aftr ttt aoaut povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf aftr using ReplyT3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lratbur shallf aftr ttt aobur povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf aftr using ReplyT3b.3.xls, append noparen nolabel coefastr se 3aster;

areg  lratlar shallf aftr ttt aolar povrate Unemprt rpcpi rpcui rpcim rpcrpo popc ppbm1019-ppnf65o ry* [aweight=popc], absorb(FIPSID) cluster(FIPSSTAT) robust;
outreg shallf aftr using ReplyT3b.3.xls, append noparen nolabel coefastr se 3aster;

log close;


